@@ -4,10 +4,12 @@ NULL
 #' @export
 #' @rdname geom_abline
 geom_hline <- function(mapping = NULL, data = NULL,
+                       stat = "identity", position = "identity",
                        ...,
                        yintercept,
                        na.rm = FALSE,
-                       show.legend = NA) {
+                       show.legend = NA,
+                      inherit.aes = FALSE) {
 
   # Act like an annotation
   if (!missing(yintercept)) {
@@ -27,11 +29,11 @@ geom_hline <- function(mapping = NULL, data = NULL,
   layer(
     data = data,
     mapping = mapping,
-    stat = StatIdentity,
+    stat = stat,
     geom = GeomHline,
-    position = PositionIdentity,
+    position = position,
     show.legend = show.legend,
-    inherit.aes = FALSE,
+    inherit.aes = inherit.aes,
     params = list2(
       na.rm = na.rm,
       ...
@@ -39,7 +41,7 @@ geom_hline <- function(mapping = NULL, data = NULL,
   )
 }
 
-#' @rdname ggplot2-ggproto
+#' @rdname Geom
 #' @format NULL
 #' @usage NULL
 #' @export
@@ -55,7 +57,12 @@ GeomHline <- ggproto("GeomHline", Geom,
     GeomSegment$draw_panel(unique0(data), panel_params, coord, lineend = lineend)
   },
 
-  default_aes = aes(colour = "black", linewidth = 0.5, linetype = 1, alpha = NA),
+  default_aes = aes(
+    colour = from_theme(colour %||% ink),
+    linewidth = from_theme(linewidth),
+    linetype = from_theme(linetype),
+    alpha = NA
+  ),
   required_aes = "yintercept",
 
   draw_key = draw_key_path,
