@@ -3,7 +3,7 @@ test_that("binwidth is respected", {
   base <- ggplot(df, aes(x, y)) +
     stat_bin_2d(geom = "tile", binwidth = 0.25)
 
-  out <- layer_data(base)
+  out <- get_layer_data(base)
   expect_equal(nrow(out), 2)
   # Adjust tolerance to account for fuzzy breaks adjustment
   expect_equal(out$xmin, c(1, 1.75), tolerance = 1e-7)
@@ -14,7 +14,7 @@ test_that("binwidth is respected", {
   expect_snapshot_warning(ggplot_build(p))
 
   p <- ggplot(df, aes(x, y)) +
-    stat_bin_2d(geom = "tile", origin = c(0.25, 0.5, 0.75))
+    stat_bin_2d(geom = "tile", boundary = c(0.25, 0.5, 0.75))
   expect_snapshot_warning(ggplot_build(p))
 })
 
@@ -31,9 +31,9 @@ test_that("breaks override binwidth", {
       binwidth = c(0.5, 0.5)
     )
 
-  out <- layer_data(base)
-  expect_equal(out$xbin, cut(df$x, adjust_breaks(integer_breaks), include.lowest = TRUE, labels = FALSE))
-  expect_equal(out$ybin, cut(df$y, adjust_breaks(half_breaks), include.lowest = TRUE, labels = FALSE))
+  out <- get_layer_data(base)
+  expect_equal(out$xbin, cut(df$x, bins(integer_breaks)$fuzzy, include.lowest = TRUE, labels = FALSE))
+  expect_equal(out$ybin, cut(df$y, bins(half_breaks)$fuzzy, include.lowest = TRUE, labels = FALSE))
 })
 
 test_that("breaks are transformed by the scale", {
@@ -42,8 +42,8 @@ test_that("breaks are transformed by the scale", {
     stat_bin_2d(
       breaks = list(x = c(5, 50, 500), y = c(0.5, 1.5, 2.5)))
 
-  out1 <- layer_data(base)
-  out2 <- layer_data(base + scale_x_log10())
+  out1 <- get_layer_data(base)
+  out2 <- get_layer_data(base + scale_x_log10())
   expect_equal(out1$x, c(27.5, 275))
   expect_equal(out2$x, c(1.19897, 2.19897))
 })
